@@ -1,9 +1,6 @@
 /* iCalPerson+SOGo.h - this file is part of SOGo
  *
- * Copyright (C) 2007-2012 Inverse inc.
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
- *         Ludovic Marcotte <lmarcotte@inverse.ca>
+ * Copyright (C) 2007-2015 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +29,8 @@
 
 - (NSString *) mailAddress;
 - (NSString *) uid;
+- (NSString *) uidInDomain: (NSString *) domain;
+- (NSString *) uidInContext: (WOContext *) context;
 - (NSString *) contactIDInContext: (WOContext *) context;
 - (BOOL) hasSentBy;
 - (NSString *) sentBy;
