@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2009-2020 Inverse inc.
+  Copyright (C) 2009-2021 Inverse inc.
 
   This file is part of SOGo.
 
@@ -78,6 +78,7 @@ typedef enum {
 - (BOOL) hasCapability: (NSString *) capability;
 - (BOOL) supportsQuotas;
 - (BOOL) supportsQResync;
+- (BOOL) supportsMove;
 
 - (id) getInboxQuota;
 - (NSException *) updateFilters;
@@ -88,6 +89,7 @@ typedef enum {
 
 - (NSArray *) identities;
 - (NSDictionary *) defaultIdentity;
+- (BOOL) forceDefaultIdentity;
 - (NSDictionary *) identityForEmail: (NSString *) email;
 - (NSString *) signature;
 - (NSString *) encryption;
