@@ -267,6 +267,11 @@ static NSString *inboxFolderName = @"INBOX";
   return [self hasCapability: @"qresync"];
 }
 
+- (BOOL) supportsMove
+{
+  return [self hasCapability: @"move"];
+}
+
 - (id) getInboxQuota
 {
   SOGoMailFolder *inbox;
@@ -289,11 +294,24 @@ static NSString *inboxFolderName = @"INBOX";
       if (quota != 0 && inboxQuota != nil)
 	{
 	  // A soft quota ratio is imposed for all users
-	  quota = quota * [(NSNumber*)[inboxQuota objectForKey: @"maxQuota"] intValue];
-	  inboxQuota = [NSDictionary dictionaryWithObjectsAndKeys:
-					[NSNumber numberWithLong: (long)(quota+0.5)], @"maxQuota",
-                                         [NSNumber numberWithLong: [[inboxQuota objectForKey: @"usedSpace"] longLongValue]], @"usedSpace",
-				     nil];
+          if ([[inboxQuota allKeys] containsObject: @"maxQuota"])
+            {
+              // Storage quota
+              quota = quota * [(NSNumber*)[inboxQuota objectForKey: @"maxQuota"] intValue];
+              inboxQuota = [NSDictionary dictionaryWithObjectsAndKeys:
+                                             [NSNumber numberWithLong: (long)(quota+0.5)], @"maxQuota",
+                                             [NSNumber numberWithLong: [[inboxQuota objectForKey: @"usedSpace"] longLongValue]], @"usedSpace",
+                                         nil];
+            }
+          else if ([[inboxQuota allKeys] containsObject: @"maxMessages"])
+            {
+              // Messages quota
+              quota = quota * [(NSNumber*)[inboxQuota objectForKey: @"maxMessages"] intValue];
+              inboxQuota = [NSDictionary dictionaryWithObjectsAndKeys:
+                                             [NSNumber numberWithLong: (long)(quota+0.5)], @"maxMessages",
+                                             [NSNumber numberWithLong: [[inboxQuota objectForKey: @"messagesCount"] longLongValue]], @"messagesCount",
+                                         nil];
+            }
 	}
     }
 
@@ -415,10 +433,9 @@ static NSString *inboxFolderName = @"INBOX";
           [folderPaths addObject: namespace];
         }
     }
-  [folderPaths
-    sortUsingSelector: @selector (localizedCaseInsensitiveCompare:)];
+  [folderPaths sortUsingSelector: @selector (localizedCaseInsensitiveCompare:)];
   [folderPaths replaceObjectsInRange: NSMakeRange (0, 0)
-	       withObjectsFromArray: mainFolders];
+                withObjectsFromArray: mainFolders];
 
   return folderPaths;
 }
@@ -429,15 +446,18 @@ static NSString *inboxFolderName = @"INBOX";
 - (NSString *) _folderType: (NSString *) folderName
                      flags: (NSMutableArray *) flags
 {
-  NSString *folderType, *key;
-  NSDictionary *metadata;
+  static NSDictionary *metadata = nil;
+  NSString *folderType, *key, *rights;
   SOGoUserDefaults *ud;
 
-  ud = [[context activeUser] userDefaults];
-
-  metadata = [[[self imap4Connection] allFoldersMetadataForURL: [self imap4URL]
-                                         onlySubscribedFolders: [ud mailShowSubscribedFoldersOnly]]
-               objectForKey: @"list"];
+  if (!metadata)
+    {
+      ud = [[context activeUser] userDefaults];
+      metadata = [[[self imap4Connection] allFoldersMetadataForURL: [self imap4URL]
+                                             onlySubscribedFolders: [ud mailShowSubscribedFoldersOnly]]
+                   objectForKey: @"list"];
+      [metadata retain];
+    }
 
   key = [NSString stringWithFormat: @"/%@", folderName];
   [flags addObjectsFromArray: [metadata objectForKey: key]];
@@ -464,7 +484,22 @@ static NSString *inboxFolderName = @"INBOX";
   else if ([folderName isEqualToString: sharedFoldersName])
     folderType = @"shared";
   else
-    folderType = @"folder";
+    {
+      folderType = @"folder";
+      if (([sharedFoldersName length] && [folderName hasPrefix: sharedFoldersName]) ||
+          ([otherUsersFolderName length] && [folderName hasPrefix: otherUsersFolderName]))
+        {
+          rights = [[self imap4Connection] myRightsForMailboxAtURL: [NSURL URLWithString: folderName]];
+          if (![rights isKindOfClass: [NSException class]] &&
+              ([rights rangeOfString: @"r"].location == NSNotFound))
+            {
+              [flags addObjectUniquely: @"noselect"];
+              if ([rights rangeOfString: @"i"].location != NSNotFound)
+                // No read but insert = dropbox
+                folderType = @"dropbox";
+            }
+        }
+    }
 
   return folderType;
 }
@@ -488,6 +523,7 @@ static NSString *inboxFolderName = @"INBOX";
   parentIsOtherUsersFolder = NO;
   pathComponents = [folderPath pathComponents];
   count = [pathComponents count];
+  currentPath = @"";
 
   // Make sure all ancestors exist.
   // The variable folderPath is something like '/INBOX/Junk' so pathComponents becomes ('/', 'INBOX', 'Junk').
@@ -496,7 +532,10 @@ static NSString *inboxFolderName = @"INBOX";
     {
       last = ((count - i) == 1);
       folder = nil;
-      currentPath = [[[pathComponents subarrayWithRange: NSMakeRange(0,i+1)] componentsJoinedByString: @"/"] substringFromIndex: 2];
+      if ([currentPath length])
+        currentPath = [NSString stringWithFormat: @"%@/%@", currentPath, [pathComponents objectAtIndex: i]];
+      else
+        currentPath = [pathComponents objectAtIndex: i];
 
       // Search for the current path in the children of the parent folder.
       // For the first iteration, take the parent folder passed as argument.
