@@ -769,6 +769,17 @@ static NSInteger _compareFetchResultsByUID (id entry1, id entry2, NSArray *uids)
                                     [self logWithFormat: @"ERROR: Can't append message: %@", result];
                                 }
                             }
+                          if (!copy && result == nil)
+                            {
+                              // Delete messages
+                              result = [client storeFlags: [NSArray arrayWithObject: @"Deleted"]
+                                                  forUIDs: uids addOrRemove: YES];
+                              if ([[result valueForKey: @"result"] boolValue])
+                                {
+                                  [self markForExpunge];
+                                  result = nil;
+                                }
+                            }
                         }
                       else
                         {
@@ -2169,11 +2180,12 @@ static NSInteger _compareFetchResultsByUID (id entry1, id entry2, NSArray *uids)
   if ([self imap4Connection])
     {
       NSDictionary *result;
-      unsigned int modseq, uid;
+      unsigned int uid;
+      uint64_t modseq;
 
       uid = [theId intValue];
       result = [[imap4 client] fetchModseqForUid: uid];
-      modseq = [[[[result objectForKey: @"RawResponse"]  objectForKey: @"fetch"] objectForKey: @"modseq"] intValue];
+      modseq = [[[[result objectForKey: @"RawResponse"]  objectForKey: @"fetch"] objectForKey: @"modseq"] longLongValue];
       
       if (modseq < 1)
         modseq = 1;
@@ -2194,14 +2206,16 @@ static NSInteger _compareFetchResultsByUID (id entry1, id entry2, NSArray *uids)
     {
       NSString *folderName;
       NSDictionary *result;
+      NSArray *keys;
 
       folderName = [imap4 imap4FolderNameForURL: [self imap4URL]];
 
       [[imap4 client] unselect];
       
       result = [[imap4 client] select: folderName];
-
-      tag = [NSString stringWithFormat: @"%@-%@", [result objectForKey: @"uidnext"], [result objectForKey: @"highestmodseq"]];
+      keys = [result allKeys];
+      if ([keys containsObject: @"uidnext"] && [keys containsObject: @"highestmodseq"])
+        tag = [NSString stringWithFormat: @"%@-%@", [result objectForKey: @"uidnext"], [result objectForKey: @"highestmodseq"]];
     }
 
   return tag;
@@ -2309,7 +2323,8 @@ static NSInteger _compareFetchResultsByUID (id entry1, id entry2, NSArray *uids)
   NSDictionary *d;
   id fetchResults, sortedResults;
 
-  int highestmodseq = 0, i;
+  int i;
+  uint64_t highestmodseq = 0;
 
   allTokens = [NSMutableArray array];
   pool = [[NSAutoreleasePool alloc] init];
@@ -2317,7 +2332,7 @@ static NSInteger _compareFetchResultsByUID (id entry1, id entry2, NSArray *uids)
   if (![theSyncToken isEqualToString: @"-1"])
     {
       a = [theSyncToken componentsSeparatedByString: @"-"];
-      highestmodseq = [[a objectAtIndex: 1] intValue];
+      highestmodseq = [[a objectAtIndex: 1] longLongValue];
     }
   
   // We first make sure QRESYNC is enabled
