@@ -30,7 +30,7 @@
   SOGoMailObject *sourceMail;
   NSString *field;
   NSString *currentValue;
-  BOOL htmlComposition;
+  BOOL htmlComposition, forceDefaultIdentity;
   NSString *signaturePlacement;
 }
 
@@ -43,9 +43,15 @@
 @interface SOGoMailArabicForward : SOGoMailForward
 @end
 
+@interface SOGoMailBosnianForward : SOGoMailForward
+@end
+
 @interface SOGoMailBrazilianPortugueseForward : SOGoMailForward
 @end
 
+@interface SOGoMailBulgarianForward : SOGoMailForward
+@end
+
 @interface SOGoMailCatalanForward : SOGoMailForward
 @end
 
@@ -106,6 +112,9 @@
 @interface SOGoMailMacedonianForward : SOGoMailForward
 @end
 
+@interface SOGoMailMontenegrinForward : SOGoMailForward
+@end
+
 @interface SOGoMailNorwegianBokmalForward : SOGoMailForward
 @end
 
