@@ -90,9 +90,15 @@
 @implementation SOGoMailArabicReply
 @end
 
+@implementation SOGoMailBosnianReply
+@end
+
 @implementation SOGoMailBrazilianPortugueseReply
 @end
 
+@implementation SOGoMailBulgarianReply
+@end
+
 @implementation SOGoMailCatalanReply
 @end
 
@@ -153,6 +159,9 @@
 @implementation SOGoMailMacedonianReply
 @end
 
+@implementation SOGoMailMontenegrinReply
+@end
+
 @implementation SOGoMailNorwegianBokmalReply
 @end
 
@@ -174,6 +183,9 @@
 @implementation SOGoMailSerbianReply
 @end
 
+@implementation SOGoMailSerbianLatinReply
+@end
+
 @implementation SOGoMailSlovakReply
 @end
 
