@@ -1,6 +1,6 @@
 /* LDAPSource.m - this file is part of SOGo
  *
- * Copyright (C) 2007-2021 Inverse inc.
+ * Copyright (C) 2007-2022 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -497,6 +497,12 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
   return (NGLdapConnection *)[self connection];
 }
 
+- (void) releaseConnection: (id) connection
+{
+  if ([(NGLdapConnection *)connection isBound])
+    [(NGLdapConnection *)connection unbind];
+}
+
 - (NSString *) domain
 {
   return _domain;
