@@ -21,7 +21,7 @@
 #ifndef SOGOCACHE_H
 #define SOGOCACHE_H
 
-#import <Foundation/NSObject.h>
+#import <Foundation/Foundation.h>
 
 #include <libmemcached/memcached.h>
 
@@ -31,7 +31,6 @@
 
 @class NGImap4Connection;
 
-@class SOGoGroup;
 @class SOGoObject;
 @class SOGoUser;
 @class SOGoUserDefaults;
@@ -67,13 +66,6 @@
              withName: (NSString *) userName;
 - (id) userNamed: (NSString *) name;
 
-- (void) registerGroup: (SOGoGroup *) group
-              withName: (NSString *) groupName
-	      inDomain: (NSString *) domainName;
-
-- (id) groupNamed: (NSString *) groupName
-	 inDomain: (NSString *) domainName;
-
 - (void) registerIMAP4Connection: (NGImap4Connection *) connection
                           forKey: (NSString *) key;
 - (NGImap4Connection *) imap4ConnectionForKey: (NSString *) key;
@@ -141,6 +133,15 @@
 	 forPath: (NSString *) thePath;
 - (NSMutableDictionary *) aclsForPath: (NSString *) thePath;
 
+//
+// SOGo rate-limiting
+//
+- (void) setRequestCount: (int) theCount
+                forLogin: (NSString *) theLogin
+                interval: (unsigned int) theInterval;
+
+- (NSDictionary *) requestCountForLogin: (NSString *) theLogin;
+
 @end
 
 #endif /* SOGOCACHE_H */
