@@ -1,6 +1,6 @@
 /* SOGoUserDefaults.h - this file is part of SOGo
  *
- * Copyright (C) 2011-2017 Inverse inc.
+ * Copyright (C) 2011-2021 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -133,6 +133,9 @@ extern NSString *SOGoWeekStartFirstFullWeek;
 - (void) setAnimationMode: (NSString *) newValue;
 - (NSString *) animationMode;
 
+- (BOOL) totpEnabled;
+- (void) setTotpEnabled: (BOOL) newValue;
+
 - (void) setMailComposeWindow: (NSString *) newValue;
 - (NSString *) mailComposeWindow;
 
@@ -145,6 +148,10 @@ extern NSString *SOGoWeekStartFirstFullWeek;
 - (void) setMailDisplayRemoteInlineImages: (NSString *) newValue;
 - (NSString *) mailDisplayRemoteInlineImages;
 
+
+- (void) setMailAutoMarkAsReadDelay: (int) newValue;
+- (int) mailAutoMarkAsReadDelay;
+
 - (void) setMailAutoSave: (NSString *) newValue;
 - (NSString *) mailAutoSave;
 
@@ -154,21 +161,9 @@ extern NSString *SOGoWeekStartFirstFullWeek;
 - (void) setMailReplyPlacement: (NSString *) newValue;
 - (NSString *) mailReplyPlacement;
 
-- (void) setMailSignature: (NSString *) newValue;
-- (NSString *) mailSignature;
-
 - (void) setMailSignaturePlacement: (NSString *) newValue;
 - (NSString *) mailSignaturePlacement;
 
-- (void) setMailCustomFullName: (NSString *) newValue;
-- (NSString *) mailCustomFullName;
-
-- (void) setMailCustomEmail: (NSString *) newValue;
-- (NSString *) mailCustomEmail;
-
-- (void) setMailReplyTo: (NSString *) newValue;
-- (NSString *) mailReplyTo;
-
 - (void) setAllowUserReceipt: (BOOL) allow;
 - (BOOL) allowUserReceipt;
 - (void) setUserReceiptNonRecipientAction: (NSString *) action;
@@ -191,6 +186,12 @@ extern NSString *SOGoWeekStartFirstFullWeek;
 - (void) setMailCertificateAlwaysEncrypt: (BOOL) newValue;
 - (BOOL) mailCertificateAlwaysEncrypt;
 
+- (void) setMailIdentities: (NSArray *) newIdentites;
+- (NSArray *) mailIdentities;
+
+- (void) setMailForceDefaultIdentity: (BOOL) newValue;
+- (BOOL) mailForceDefaultIdentity;
+
 - (void) setAuxiliaryMailAccounts: (NSArray *) newAccounts;
 - (NSArray *) auxiliaryMailAccounts;
 
