@@ -1,6 +1,6 @@
 /* SOGoUserDefaults.m - this file is part of SOGo
  *
- * Copyright (C) 2009-2020 Inverse inc.
+ * Copyright (C) 2009-2021 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,10 +18,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#import <Foundation/NSData.h>
 #import <Foundation/NSDictionary.h>
 #import <Foundation/NSTimeZone.h>
 #import <Foundation/NSValue.h>
 
+#import <NGExtensions/NGBase64Coding.h>
 #import <NGImap4/NSString+Imap4.h>
 #import <NGObjWeb/WOApplication.h>
 #import <NGObjWeb/WOContext+SoObjects.h>
@@ -228,6 +230,7 @@ NSString *SOGoWeekStartFirstFullWeek = @"FirstFullWeek";
                         @"SOGoReminderEnabled", @"ReminderEnabled",
                         @"SOGoReminderTime", @"ReminderTime",
                         @"SOGoRemindWithASound", @"RemindWithASound",
+                        @"SOGoTOTPEnabled", @"SOGoGoogleAuthenticatorEnabled",
                         nil];
       [migratedKeys retain];
     }
@@ -567,14 +570,14 @@ NSString *SOGoWeekStartFirstFullWeek = @"FirstFullWeek";
   return [self stringForKey: @"SOGoAnimationMode"];
 }
 
-- (BOOL) googleAuthenticatorEnabled
+- (BOOL) totpEnabled
 {
-  return [self boolForKey: @"SOGoGoogleAuthenticatorEnabled"];
+  return [self boolForKey: @"SOGoTOTPEnabled"];
 }
 
-- (void) setGoogleAuthenticatorEnabled: (BOOL) newValue
+- (void) setTotpEnabled: (BOOL) newValue
 {
-  [self setBool: newValue  forKey: @"SOGoGoogleAuthenticatorEnabled"];
+  [self setBool: newValue  forKey: @"SOGoTOTPEnabled"];
 }
 
 - (void) setMailComposeWindow: (NSString *) newValue
@@ -617,6 +620,16 @@ NSString *SOGoWeekStartFirstFullWeek = @"FirstFullWeek";
   return [self stringForKey: @"SOGoMailDisplayRemoteInlineImages"];
 }
 
+- (void) setMailAutoMarkAsReadDelay: (int) newValue
+{
+  [self setInteger: newValue forKey: @"SOGoMailAutoMarkAsReadDelay"];
+}
+
+- (int) mailAutoMarkAsReadDelay
+{
+  return [self integerForKey: @"SOGoMailAutoMarkAsReadDelay"];
+}
+
 - (void) setMailAutoSave: (NSString *) newValue
 {
   [self setObject: newValue forKey: @"SOGoMailAutoSave"];
@@ -768,6 +781,16 @@ NSString *SOGoWeekStartFirstFullWeek = @"FirstFullWeek";
   return [self arrayForKey: @"SOGoMailIdentities"];
 }
 
+- (void) setMailForceDefaultIdentity: (BOOL) newValue
+{
+  [self setBool: newValue forKey: @"SOGoMailForceDefaultIdentity"];
+}
+
+- (BOOL) mailForceDefaultIdentity
+{
+  return [self boolForKey: @"SOGoMailForceDefaultIdentity"];
+}
+
 - (void) setAuxiliaryMailAccounts: (NSArray *) newAccounts
 {
   [self setObject: newAccounts forKey: @"AuxiliaryMailAccounts"];
