@@ -17,6 +17,9 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+
+#import <Foundation/NSAutoreleasePool.h>
+
 #import <NGExtensions/NSNull+misc.h>
 #import <NGExtensions/NSObject+Logs.h>
 
@@ -293,10 +296,8 @@ static Class NSNullK;
 
   if (!domain) return NO;
 
-  ids = [_sources allKeys];
+  ids = [[SOGoSystemDefaults sharedSystemDefaults] domainIds];
   if ([ids containsObject: domain])
-    // FIXME check SOGoMailDomain?
-    // Now source id is being considered as the domain
     return YES;
 
   sd = [SOGoSystemDefaults sharedSystemDefaults];
@@ -433,15 +434,18 @@ static Class NSNullK;
                            perr: (SOGoPasswordPolicyError *) perr
 {
   NSObject <SOGoSource> *sogoSource;
-  NSEnumerator *authIDs;
   NSString *currentID;
   BOOL didChange;
 
+  *perr = -1;
   didChange = NO;
 
-  authIDs = [[self authenticationSourceIDsInDomain: domain] objectEnumerator];
-  while (!didChange && (currentID = [authIDs nextObject]))
+  NSDictionary *info = [self contactInfosForUserWithUIDorEmail: login
+                                                      inDomain: domain];
+
+  if (info)
     {
+      currentID = [info objectForKey: @"SOGoSource"];
       sogoSource = [_sources objectForKey: currentID];
       didChange = [sogoSource changePasswordForLogin: login
                                          oldPassword: oldPassword
@@ -544,7 +548,7 @@ static Class NSNullK;
 
   username = _login;
 
-  if (*_domain)
+  if (*_domain && ![*_domain isKindOfClass: NSNullK])
     {
       if ([_login rangeOfString: @"@"].location == NSNotFound)
         username = [NSString stringWithFormat: @"%@@%@", _login, *_domain];
@@ -557,6 +561,7 @@ static Class NSNullK;
       // sources if SOGoLoginDomains isn't specified. This is also true if the user is
       // using DAV or EAS.
       r = [username rangeOfString: @"@"];
+      *_domain = nil;
 
       if (r.location != NSNotFound)
         {
@@ -1020,7 +1025,7 @@ static Class NSNullK;
     {
       // Remove the "@" prefix used to identified groups in the ACL tables.
       aUID = [uid hasPrefix: @"@"] ? [uid substringFromIndex: 1] : uid;
-      if (domain && [aUID rangeOfString: @"@"].location == NSNotFound)
+      if ([domain length] && [aUID rangeOfString: @"@"].location == NSNotFound)
         cacheUid = [NSString stringWithFormat: @"%@@%@", aUID, domain];
       else
         cacheUid = aUID;
@@ -1031,7 +1036,7 @@ static Class NSNullK;
       if ([currentUser isKindOfClass: NSNullK])
         currentUser = nil;
       else if (!([currentUser objectForKey: @"emails"]
-            && [currentUser objectForKey: @"cn"]))
+                 && [currentUser objectForKey: @"cn"]))
         {
           // We make sure that we either have no occurence of a cache entry or
           // that we have an occurence with only a cached password. In the
@@ -1200,6 +1205,7 @@ static Class NSNullK;
                             matching: (NSString *) filter
                             inDomain: (NSString *) domain
 {
+  NSAutoreleasePool *pool;
   NSMutableArray *contacts;
   NSEnumerator *sources;
   NSString *sourceID;
@@ -1209,11 +1215,13 @@ static Class NSNullK;
   sources = [sourcesList objectEnumerator];
   while ((sourceID = [sources nextObject]))
     {
+      pool = [[NSAutoreleasePool alloc] init];
       currentSource = [_sources objectForKey: sourceID];
       [contacts addObjectsFromArray:
                   [currentSource fetchContactsMatching: filter
                                           withCriteria: nil
                                               inDomain: domain]];
+      RELEASE(pool);
     }
 
   return [self _compactAndCompleteContacts: [contacts objectEnumerator]];
@@ -1231,10 +1239,9 @@ static Class NSNullK;
 - (NSArray *) fetchUsersMatching: (NSString *) filter
                         inDomain: (NSString *) domain
 {
-  return [self
-           _fetchEntriesInSources: [self authenticationSourceIDsInDomain: domain]
-                         matching: filter
-                         inDomain: domain];
+  return [self _fetchEntriesInSources: [self authenticationSourceIDsInDomain: domain]
+                             matching: filter
+                             inDomain: domain];
 }
 
 - (NSString *) getLoginForDN: (NSString *) theDN
