@@ -1,6 +1,6 @@
 /* SQLSource.h - this file is part of SOGo
  *
- * Copyright (C) 2009-2021 Inverse inc.
+ * Copyright (C) 2009-2022 Inverse inc.
  *
  * This file is part of SOGo.
  *
@@ -440,6 +440,17 @@
   return channel;
 }
 
+- (void) releaseConnection: (id) connection
+{
+  GCSChannelManager *cm;
+
+  if (connection)
+    {
+      cm = [GCSChannelManager defaultChannelManager];
+      [cm releaseChannel: connection];
+    }
+}
+
 - (NSDictionary *) _lookupContactEntry: (NSString *) theID
                          considerEmail: (BOOL) b
                               inDomain: (NSString *) domain
@@ -487,13 +498,8 @@
         }
 
       domainQualifier = nil;
-      if (_domainField && domain)
-        {
-          domainQualifier = [[EOKeyValueQualifier alloc] initWithKey: _domainField
-                                                    operatorSelector: EOQualifierOperatorEqual
-                                                               value: domain];
-          [domainQualifier autorelease];
-        }
+      if (_domainField && [domain length])
+        domainQualifier = [self visibleDomainsQualifierFromDomain: domain];
 
       if (b)
         {
@@ -683,18 +689,16 @@
                               inDomain: (NSString *) domain
 {
   EOAdaptorChannel *channel;
-  GCSChannelManager *cm;
   NSDictionary *response;
 
-  cm = [GCSChannelManager defaultChannelManager];
   channel = (EOAdaptorChannel *)[self connection];
 
   response = [self _lookupContactEntry: theID
 			 considerEmail: b
 			      inDomain: domain
 		       usingConnection: channel];
-  if (channel)
-    [cm releaseChannel: channel];
+
+  [self releaseConnection: channel];
 
   return response;
 }
@@ -727,7 +731,7 @@
  * (_domainField = domain OR _domainField = visibleDomain1 [...])
  * Should only be called on SQL sources using _domainField name.
  */
-- (EOQualifier *) _visibleDomainsQualifierFromDomain: (NSString *) domain
+- (EOQualifier *) visibleDomainsQualifierFromDomain: (NSString *) domain
 {
   int i;
   EOQualifier *qualifier, *domainQualifier;
@@ -745,10 +749,9 @@
   visibleDomains = [sd visibleDomainsForDomain: domain];
   qualifier = nil;
 
-  domainQualifier =
-    [[EOKeyValueQualifier alloc] initWithKey: _domainField
-                            operatorSelector: EOQualifierOperatorEqual
-                                       value: domain];
+  domainQualifier = [[EOKeyValueQualifier alloc] initWithKey: _domainField
+                                            operatorSelector: EOQualifierOperatorEqual
+                                                       value: domain];
   [domainQualifier autorelease];
 
   if ([visibleDomains count])
@@ -795,8 +798,7 @@
         {
           if ([domain length])
             {
-              domainQualifier =
-                [self _visibleDomainsQualifierFromDomain: domain];
+              domainQualifier = [self visibleDomainsQualifierFromDomain: domain];
               if (domainQualifier)
                 {
                   [sql appendString: @" WHERE "];
@@ -868,7 +870,7 @@
           if ([filter length])
             {
               lowerFilter = [filter lowercaseString];
-              lowerFilter = [lowerFilter asSafeSQLString];
+              lowerFilter = [lowerFilter asSafeSQLLikeString];
               filterFormat = [NSString stringWithFormat: @"LOWER(%%@) LIKE '%%%%%@%%%%'", lowerFilter];
               if (criteria)
                 criteriaList = [criteria objectEnumerator];
@@ -905,7 +907,7 @@
               if ([domain length])
                 {
                   EOQualifier *domainQualifier;
-                  domainQualifier = [self _visibleDomainsQualifierFromDomain: domain];
+                  domainQualifier = [self visibleDomainsQualifierFromDomain: domain];
                   if (domainQualifier)
                     {
                       [sql appendFormat: @" AND ("];
