@@ -53,6 +53,9 @@
 #import <Appointments/SOGoAptMailReminder.h>
 #import <WEExtensions/WEResourceManager.h>
 
+#import <GDLContentStore/GCSChannelManager.h>
+#import <GDLContentStore/GCSFolderManager.h>
+
 #import "SOGoEAlarmsNotifier.h"
 
 @implementation SOGoEAlarmsNotifier
@@ -109,7 +112,6 @@
   [headers addObject: @"high" forKey: @"Importance"];
   [headers addObject: @"1" forKey: @"X-Priority"];
   [headers setObject: @"text/html; charset=\"utf-8\"" forKey: @"Content-Type"];
-  [headers setObject: @"quoted-printable" forKey: @"Content-Transfer-Encoding"];
 
   identity = [owner primaryIdentity];
   fullName = [identity objectForKey: @"fullName"];
@@ -150,7 +152,7 @@
 {
   NGMutableHashMap *headers;
   NSArray *parts;
-  NSData *content, *qpContent;
+  NSData *content;
   SOGoMailer *mailer;
   NSString *subject;
   SOGoUser *owner;
@@ -158,7 +160,6 @@
   WOContext *localContext;
   WOApplication *app;
   SOGoAptMailReminder *p;
-  NSString *pageName;
   WOResourceManager *rm;
 
   SOGoAppointmentFolders *folders;
@@ -188,9 +189,7 @@
   folders = [userFolder privateCalendars: @"Calendar"
                                inContext: localContext];
 
-  pageName = [NSString stringWithFormat: @"SOGoAptMail%@", @"Reminder"];
-
-  p = [app pageWithName: pageName inContext: localContext];
+  p = [app pageWithName: @"SOGoAptMailReminder" inContext: localContext];
 
   parts = [containerPath componentsSeparatedByString: @"/"];
   if ([parts count] > 4)
@@ -208,9 +207,8 @@
   subject = [p getSubject];
 
   headers = [self _headersForAlarm: alarm withOwner: owner withSubject: subject];
-  qpContent = [content dataByEncodingQuotedPrintable];
   [self _sendMessageWithHeaders: headers
-                        content: qpContent
+                        content: content
                              to: [owner primaryIdentity]
                      withMailer: mailer];
 }
@@ -228,6 +226,8 @@
 
 - (BOOL) run
 {
+  GCSChannelManager *cm;
+  GCSFolderManager *fm;
   NSArray *arguments, *alarms;
   NSCalendarDate *startDate, *toDate;
   NSDictionary *d;
@@ -273,7 +273,7 @@
                                                       hour: 0 minute: -5
                                                     second: 0]
                                    toDate: toDate
-                               withMetadata: metadata];
+                             withMetadata: metadata];
 
   max = [alarms count];
   for (count = 0; count < max; count++)
@@ -282,7 +282,7 @@
        andContainerPath: [[[metadata objectAtIndex: count] objectForKey: @"record"] objectForKey: @"c_path"]];
 
   // We now update the next alarm date (if any, for recurring
-  // events or tasks for example). This will also delete any emai
+  // events or tasks for example). This will also delete any email
   // alarms that are no longer relevant
   max = [metadata count];
 
@@ -295,6 +295,10 @@
 		     nameInContainer: [[d objectForKey: @"record"] objectForKey: @"c_name"]];
     }
 
+  // GCSFolder has opened a channel; close it before ending the process
+  fm = [GCSFolderManager defaultFolderManager];
+  cm = [fm channelManager];
+  [cm releaseAllChannels];
 
   return YES;
 }
