@@ -1,6 +1,6 @@
 /* SOGoToolRemoveDoubles.m - this file is part of SOGo
  *
- * Copyright (C) 2009-2017 Inverse inc.
+ * Copyright (C) 2009-2020 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -207,7 +207,7 @@
 	  usingChannel: channel];
 
   [context commitTransaction];
-  [folder releaseChannel: channel];
+  [folder releaseChannel: channel  immediately: YES];
 }
 
 - (NSArray *) namesOfRecords: (NSArray *) records
