@@ -84,7 +84,7 @@
   if ([owner isEqualToString: login])
     {
       jsonResponse = [NSDictionary dictionaryWithObject: [self labelForKey: @"You cannot (un)subscribe to a folder that you own!"]
-                                                 forKey: @"error"];
+                                                 forKey: @"message"];
       response = [self responseWithStatus: 403
                     andJSONRepresentation: jsonResponse];
     }
@@ -289,12 +289,22 @@
   if ([folderName length] > 0)
     {
       clientObject = [self clientObject];
-      [clientObject renameTo: folderName];
-      response = [self responseWith204];
+      NS_DURING
+        {
+          [clientObject renameTo: folderName];
+          response = [self responseWith204];
+        }
+      NS_HANDLER
+        {
+          message = [NSDictionary dictionaryWithObject: [localException reason] forKey: @"message"];
+          response = [self responseWithStatus: 409 /* Conflict */
+                                    andString: [message jsonRepresentation]];
+        }
+      NS_ENDHANDLER;
     }
   else
     {
-      message = [NSDictionary dictionaryWithObject: @"Missing name parameter" forKey: @"error"];
+      message = [NSDictionary dictionaryWithObject: @"Missing name parameter" forKey: @"message"];
       response = [self responseWithStatus: 500
                                 andString: [message jsonRepresentation]];
     }
@@ -335,7 +345,7 @@
     {
       response = [self responseWithStatus: 400
                     andJSONRepresentation: [NSDictionary dictionaryWithObject: @"At least 1 id required."
-                                                                     forKey: @"error"]];
+                                                                     forKey: @"message"]];
     }
   
   return response;
