@@ -1,6 +1,6 @@
 /* UIxMailFolderActions.m - this file is part of SOGo
  *
- * Copyright (C) 2007-2018 Inverse inc.
+ * Copyright (C) 2007-2021 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 
 #import <Foundation/NSDictionary.h>
 #import <Foundation/NSURL.h>
+#import <Foundation/NSValue.h>
 
 #import <NGObjWeb/WOContext+SoObjects.h>
 #import <NGObjWeb/WORequest.h>
@@ -30,6 +31,7 @@
 
 
 #import <Mailer/SOGoMailAccount.h>
+#import <Mailer/SOGoMailFolder.h>
 #import <Mailer/SOGoTrashFolder.h>
 
 #import <SOGo/NSArray+Utilities.h>
@@ -287,12 +289,11 @@
   return response;
 }
 
-- (NSURL *) _trashedURLOfFolder: (NSURL *) srcURL
-                     withObject: (SOGoMailFolder *) co
+- (NSString *) _trashedNameOfFolder: (NSURL *) srcURL
+                         withObject: (SOGoMailFolder *) co
 {
   NSString *trashFolderName, *folderName, *path, *testPath;
   NGImap4Connection *connection;
-  NSURL *destURL;
   id test;
   int i;
 
@@ -318,14 +319,11 @@
           break;
         }
     }
-  destURL = [[NSURL alloc] initWithScheme: [srcURL scheme]
-                                     host: [srcURL host] path: path];
-  [destURL autorelease];
 
-  return destURL;
+  return path;
 }
 
-- (void) _removeFolderAtURL: (NSURL *) srcURL
+- (void) _removeFolder: (NSString *) srcName
 {
   NGImap4Connection *connection;
   NSMutableDictionary *moduleSettings, *threadsCollapsed;;
@@ -337,7 +335,7 @@
   connection = [co imap4Connection];
 
   // Unsubscribe from mailbox
-  [[connection client] unsubscribe: [srcURL path]];
+  [[connection client] unsubscribe: srcName];
 
   // Verify if the current folder have any collapsed threads save under it name and erase it
   us = [[context activeUser] userSettings];
@@ -359,21 +357,22 @@
 - (WOResponse *) deleteAction
 {
   NSDictionary *jsonRequest, *jsonResponse;
-  NSEnumerator *subURLs;
+  NSEnumerator *subNames;
   NGImap4Connection *connection;
   SOGoMailFolder *co, *inbox;
-  NSURL *srcURL, *destURL, *currentURL;
+  NSURL *srcURL;
   WORequest *request;
   WOResponse *response;
   NSException *error;
   NSInteger count;
+  NSString *destName, *currentName;
   BOOL moved, withTrash;
 
   request = [context request];
   co = [self clientObject];
   connection = [co imap4Connection];
   srcURL = [co imap4URL];
-  subURLs = [[co allFolderURLs] objectEnumerator];
+  subNames = [[co allFolderPaths] objectEnumerator];
   jsonRequest = [[request contentAsString] objectFromJSONString];
   withTrash = ![[jsonRequest objectForKey: @"withoutTrash"] boolValue];
   error = nil;
@@ -383,7 +382,7 @@
     {
       if ([co ensureTrashFolder])
         {
-          destURL = [self _trashedURLOfFolder: srcURL withObject: co];
+          destName = [self _trashedNameOfFolder: srcURL withObject: co];
           inbox = [[co mailAccountFolder] inboxFolderInContext: context];
           [[connection client] select: [inbox absoluteImap4Name]];
 
@@ -391,14 +390,14 @@
           // the folder within the 'Trash' folder, as it's getting renamed
           // over and over with an integer suffix (in trashedURLOfFolder:...)
           // If that is the case, we simple delete the folder, instead of renaming it
-          if ([[destURL path] hasPrefix: [srcURL path]])
+          if ([destName hasPrefix: [srcURL path]])
             {
               error = [connection deleteMailboxAtURL: srcURL];
               moved = NO;
             }
           else
             {
-              error = [connection moveMailboxAtURL: srcURL toURL: destURL];
+              error = [connection moveMailbox: [srcURL path] to: destName];
             }
           if (error)
             {
@@ -409,25 +408,25 @@
           else
             {
               // We unsubscribe to the old one, and subscribe back to the new one
-              [self _removeFolderAtURL: srcURL];
+              [self _removeFolder: [srcURL path]];
               if (moved)
-                [[connection client] subscribe: [destURL path]];
+                [[connection client] subscribe: destName];
 
               // We do the same for all subfolders
               count = [[srcURL pathComponents] count];
-              while (!error && (currentURL = [subURLs nextObject]))
+              while (!error && (currentName = [subNames nextObject]))
                 {
-                  [self _removeFolderAtURL: currentURL];
+                  [self _removeFolder: currentName];
                   if (moved)
                     {
                       NSArray *currentComponents;
                       NSMutableArray *destComponents;
                       NSInteger currentCount;
 
-                      destComponents = [NSMutableArray arrayWithArray: [destURL pathComponents]];
+                      destComponents = [NSMutableArray arrayWithArray: [destName  componentsSeparatedByString: @"/"]];
                       [destComponents removeObjectAtIndex: 0]; // remove leading forward slash
-                      currentCount = [[currentURL pathComponents] count];
-                      currentComponents = [[currentURL pathComponents] subarrayWithRange: NSMakeRange(count, currentCount - count)];
+                      currentCount = [[currentName componentsSeparatedByString: @"/"] count];
+                      currentComponents = [[currentName componentsSeparatedByString: @"/"] subarrayWithRange: NSMakeRange(count, currentCount - count)];
                       [destComponents addObjectsFromArray: currentComponents];
 
                       [[connection client] subscribe: [NSString stringWithFormat: @"/%@", [destComponents componentsJoinedByString: @"/"]]];
@@ -457,10 +456,10 @@
       else
         {
           // Cleanup all references to mailbox and submailboxes
-          [self _removeFolderAtURL: srcURL];
-          while (!error && (currentURL = [subURLs nextObject]))
+          [self _removeFolder: [srcURL path]];
+          while (!error && (currentName = [subNames nextObject]))
             {
-              [self _removeFolderAtURL: currentURL];
+              [self _removeFolder: currentName];
             }
           response = [self responseWith204];
         }
@@ -471,14 +470,13 @@
 
 - (WOResponse *) batchDeleteAction
 {
-  NSMutableDictionary *moduleSettings, *threadsCollapsed;
+  NSMutableDictionary *moduleSettings, *threadsCollapsed, *data;
   NSString *currentMailbox, *currentAccount, *keyForMsgUIDs;
   NSMutableArray *mailboxThreadsCollapsed;
   SOGoMailAccount *account;
   SOGoUserSettings *us;
   WOResponse *response;
   SOGoMailFolder *co;
-  NSDictionary *data;
   WORequest *request;
 
   id uids, quota;
@@ -497,18 +495,16 @@
       response = (WOResponse *) [co deleteUIDs: uids useTrashFolder: &withTrash inContext: context];
       if (!response)
         {
+          data = [NSMutableDictionary dictionary];
           if (!withTrash)
             {
               // When not using a trash folder, return the quota
               account = [co mailAccountFolder];
               if ((quota = [account getInboxQuota]))
                 {
-                  data = [NSDictionary dictionaryWithObjectsAndKeys: quota, @"quotas", nil];
-                  response = [self responseWithStatus: 200
-                                            andString: [data jsonRepresentation]];
+                  [data setObject: quota
+                           forKey: @"quotas"];
                 }
-              else
-                response = [self responseWithStatus: 200];
             }
           else
             {
@@ -522,15 +518,18 @@
 
               if (threadsCollapsed)
                 {
-                  if ((mailboxThreadsCollapsed = [threadsCollapsed objectForKey:keyForMsgUIDs]))
+                  if ((mailboxThreadsCollapsed = [threadsCollapsed objectForKey: keyForMsgUIDs]))
                     {
                       for (i = 0; i < [uids count]; i++)
-                        [mailboxThreadsCollapsed removeObject:[uids objectAtIndex:i]];
+                        [mailboxThreadsCollapsed removeObject: [uids objectAtIndex:i]];
                       [us synchronize];
                     }
                 }
-              response = [self responseWith204];
             }
+          [data setObject: [NSNumber numberWithUnsignedInt: [co unseenCount]]
+                   forKey: @"unseenCount"];
+          response = [self responseWithStatus: 200
+                                    andString: [data jsonRepresentation]];
         }
     }
   else
@@ -684,7 +683,9 @@
                   [us synchronize];
                 }
             }
-          response = [self responseWith204];
+          data = [NSDictionary dictionaryWithObject: [NSNumber numberWithUnsignedInt: [co unseenCount]]
+                                             forKey: @"unseenCount"];
+          response = [self responseWithStatus: 200 andJSONRepresentation: data];
         }
       else
         {
@@ -876,15 +877,25 @@
   return response;
 }
 
+- (WOResponse *) emptyJunkAction
+{
+  return [self emptySpecialFolderAction: @"junk"];
+}
+
 - (WOResponse *) emptyTrashAction
+{
+  return [self emptySpecialFolderAction: @"trash"];
+}
+
+- (WOResponse *) emptySpecialFolderAction: (NSString *) folderType
 {
   NSException *error;
-  SOGoTrashFolder *co;
+  SOGoSpecialMailFolder *co;
   SOGoMailAccount *account;
   NSEnumerator *subfolders;
   WOResponse *response;
   NGImap4Connection *connection;
-  NSURL *currentURL;
+  NSString *currentName, *errorMsg;
   NSDictionary *data;
 
   id quota;
@@ -900,16 +911,17 @@
 
       // Delete folders within the trash
       connection = [co imap4Connection];
-      subfolders = [[co allFolderURLs] objectEnumerator];
-      while ((currentURL = [subfolders nextObject]))
+      subfolders = [[co allFolderPaths] objectEnumerator];
+      while ((currentName = [subfolders nextObject]))
         {
-          [[connection client] unsubscribe: [currentURL path]];
-          [connection deleteMailboxAtURL: currentURL];
+          [[connection client] unsubscribe: currentName];
+          [connection deleteMailbox: currentName];
         }
     }
   if (error)
     {
-      data = [NSDictionary dictionaryWithObject: [self labelForKey: @"Unable to empty the trash folder." inContext: context]
+      errorMsg = [NSString stringWithFormat: @"Unable to empty the %@ folder.", folderType];
+      data = [NSDictionary dictionaryWithObject: [self labelForKey: errorMsg inContext: context]
                                          forKey: @"message"];
       response = [self responseWithStatus: 500 andJSONRepresentation: data];
     }
@@ -987,6 +999,63 @@
   return [self _subscribeOrUnsubscribeAction: NO];
 }
 
+- (id <WOActionResults>) getLabelsAction
+{
+  NGImap4Client *client;
+  NSArray *labels, *userLabel;
+  NSDictionary *result, *userLabels, *labelRecord;
+  NSEnumerator *labelsList;
+  NSMutableArray *allLabels;
+  NSString *label;
+  SOGoMailFolder *co;
+  WOResponse *response;
+  unsigned int i;
+  static NSArray *imapKeywords = nil;
+
+  if (!imapKeywords)
+    {
+      imapKeywords = [[NSArray alloc] initWithObjects: @"ANSWERED", @"DELETED",
+                                      @"DRAFT", @"FLAGGED", @"NEW", @"OLD", @"RECENT",
+                                      @"SEEN", @"UNANSWERED", @"UNDELETED", @"UNDRAFT",
+                                      @"UNFLAGGED", @"UNSEEN", nil];
+      [imapKeywords retain];
+    }
+
+  i = 0;
+  allLabels = [NSMutableArray array];
+  co = [self clientObject];
+  client = [[co imap4Connection] client];
+  result = [client select: [[co imap4URL] path]];
+  labels = [result objectForKey: @"flags"];
+  userLabels = [[[context activeUser] userDefaults] mailLabelsColors];
+  labelsList = [[labels sortedArrayUsingSelector: @selector(compareAscending:)] objectEnumerator];
+  while ((label = [labelsList nextObject]))
+    {
+      if (![imapKeywords containsObject: [label uppercaseString]])
+        {
+          if ((userLabel = [userLabels objectForKey: label]))
+            {
+              labelRecord = [NSDictionary dictionaryWithObjectsAndKeys:
+                                            label, @"imapName",
+                                              [userLabel objectAtIndex: 0], @"name",
+                                              [userLabel objectAtIndex: 1], @"color", nil];
+              [allLabels insertObject: labelRecord atIndex: i];
+              i++;
+            }
+          else
+            {
+              labelRecord = [NSDictionary dictionaryWithObjectsAndKeys:
+                                            label, @"imapName", nil];
+              [allLabels addObject: labelRecord];
+            }
+        }
+    }
+
+  response = [self responseWithStatus: 200 andJSONRepresentation: allLabels];
+
+  return response;
+}
+
 - (WOResponse *) addOrRemoveLabelAction
 {
   WOResponse *response;
