@@ -180,11 +180,6 @@ static NSString *mailETag = nil;
   return attachmentAttrs;
 }
 
-- (BOOL) hasAttachments
-{
-  return [[self attachmentAttrs] count] > 0 ? YES : NO;
-}
-
 - (NSFormatter *) sizeFormatter
 {
   return [UIxMailSizeFormatter sharedMailSizeFormatter];
@@ -199,14 +194,6 @@ static NSString *mailETag = nil;
   return [formatter stringForObjectValue: [[self clientObject] date]];
 }
 
-- (NSString *) attachmentsText
-{
-  if ([[self attachmentAttrs] count] > 1)
-    return [self labelForKey: @"files"];
-  else
-    return [self labelForKey: @"file"];
-}
-
 /* viewers */
 
 //
@@ -234,12 +221,18 @@ static NSString *mailETag = nil;
       for (count = 0; count < max; count++)
         {
           attributes = [[self attachmentAttrs] objectAtIndex: count];
-          filename = [NSString stringWithFormat: @"<%@>", [attributes objectForKey: @"filename"]];
-          [attachmentIds setObject: [attributes objectForKey: @"url"]
-                            forKey: filename];
-          if ([[attributes objectForKey: @"bodyId"] length])
-            [attachmentIds setObject: [attributes objectForKey: @"url"]
-                              forKey: [attributes objectForKey: @"bodyId"]];
+
+          // Don't allow XML inline attachments
+          if (![[attributes objectForKey: @"mimetype"] hasSuffix: @"xml"] &&
+              ![[[attributes objectForKey: @"filename"] lowercaseString] hasSuffix: @"svg"])
+            {
+              filename = [NSString stringWithFormat: @"<%@>", [attributes objectForKey: @"filename"]];
+              [attachmentIds setObject: [attributes objectForKey: @"url"]
+                                forKey: filename];
+              if ([[attributes objectForKey: @"bodyId"] length])
+                [attachmentIds setObject: [attributes objectForKey: @"url"]
+                                  forKey: [attributes objectForKey: @"bodyId"]];
+            }
         }
       // Attachment IDs will be decoded in UIxMailPartEncryptedViewer for
       // S/MIME encrypted emails with file attachments.
@@ -285,10 +278,13 @@ static NSString *mailETag = nil;
   NSMutableDictionary *data;
   NSArray *addresses;
   SOGoMailObject *co;
+  SOGoUserDefaults *ud;
   UIxEnvelopeAddressFormatter *addressFormatter;
   UIxMailRenderingContext *mctx;
+  id viewer, renderedPart;
 
   co = [self clientObject];
+  ud = [[context activeUser] userDefaults];
   addressFormatter = [context mailEnvelopeAddressFormatter];
 
   mctx = [[UIxMailRenderingContext alloc] initWithViewer: self context: context];
@@ -338,11 +334,13 @@ static NSString *mailETag = nil;
                 andJSONRepresentation: data];
     }
 
+  viewer = [self contentViewerComponent]; // set attachmentIds for common parts
+  renderedPart = [viewer renderedPart];   // set attachmentIds for encrypted & TNEF parts
+
   data = [NSMutableDictionary dictionaryWithObjectsAndKeys:
-                       [self attachmentAttrs], @"attachmentAttrs",
                        [self shouldAskReceipt], @"shouldAskReceipt",
                        [NSNumber numberWithBool: [self mailIsDraft]], @"isDraft",
-                       [[self contentViewerComponent] renderedPart], @"parts",
+                       renderedPart, @"parts",
                        nil];
   if ([self formattedDate])
     [data setObject: [self formattedDate] forKey: @"date"];
@@ -359,8 +357,11 @@ static NSString *mailETag = nil;
   if ((addresses = [addressFormatter dictionariesForArray: [co replyToEnvelopeAddresses]]))
     [data setObject: addresses forKey: @"reply-to"];
 
-  // Mark message as read
-  [co addFlags: @"seen"];
+  if ([ud mailAutoMarkAsReadDelay] == 0)
+    // Mark message as read
+    [co addFlags: @"seen"];
+
+  [data setObject: [NSNumber numberWithBool: [co read]] forKey: @"isRead"];
 
   response = [self responseWithStatus: 200
                 andJSONRepresentation: data];
