@@ -1,6 +1,6 @@
 /* UIxJSONPreferences.m - this file is part of SOGo
  *
- * Copyright (C) 2007-2020 Inverse inc.
+ * Copyright (C) 2007-2021 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -172,8 +172,8 @@ static SoProduct *preferencesProduct = nil;
   if (![[defaults source] objectForKey: @"SOGoAnimationMode"])
     [[defaults source] setObject: [defaults animationMode]  forKey: @"SOGoAnimationMode"];
 
-  if (![[defaults source] objectForKey: @"SOGoGoogleAuthenticatorEnabled"])
-    [[defaults source] setObject: [NSNumber numberWithBool: NO]  forKey: @"SOGoGoogleAuthenticatorEnabled"];
+  if (![[defaults source] objectForKey: @"SOGoTOTPEnabled"])
+    [[defaults source] setObject: [NSNumber numberWithBool: NO]  forKey: @"SOGoTOTPEnabled"];
 
   //
   // Default Calendar preferences
@@ -342,6 +342,9 @@ static SoProduct *preferencesProduct = nil;
   if (![[defaults source] objectForKey: @"SOGoMailDisplayRemoteInlineImages"])
     [[defaults source] setObject: [defaults mailDisplayRemoteInlineImages] forKey: @"SOGoMailDisplayRemoteInlineImages"];
 
+  if ([[defaults source] objectForKey: @"SOGoMailAutoMarkAsReadDelay"] == nil)
+    [[defaults source] setObject: [NSNumber numberWithInt: [defaults mailAutoMarkAsReadDelay]] forKey: @"SOGoMailAutoMarkAsReadDelay"];
+
   if (![[defaults source] objectForKey: @"SOGoMailAutoSave"])
     [[defaults source] setObject: [defaults mailAutoSave] forKey: @"SOGoMailAutoSave"];
 
@@ -410,7 +413,7 @@ static SoProduct *preferencesProduct = nil;
         {
           auxAccount = [accounts objectAtIndex: i];
           security = [auxAccount objectForKey: @"security"];
-          if (security)
+          if (security && [domainDefaults mailCertificateEnabled])
             {
               limitedSecurity = [NSMutableDictionary dictionaryWithDictionary: security];
               if ([limitedSecurity objectForKey: @"certificate"])
@@ -441,6 +444,7 @@ static SoProduct *preferencesProduct = nil;
   [values removeObjectForKey: @"SOGoMailCertificate"];
   [values removeObjectForKey: @"SOGoMailCertificateAlwaysSign"];
   [values removeObjectForKey: @"SOGoMailCertificateAlwaysEncrypt"];
+  [values removeObjectForKey: @"SOGoMailForceDefaultIdentity"];
 
   // Add the domain's default vacation subject if user has not specified a custom subject
   vacationOptions = [defaults vacationOptions];
