@@ -53,12 +53,30 @@
 @interface SOGoFolderRemovalAdvisory : SOGoFolderAdvisory
 @end
 
+@interface SOGoFolderArabicAdditionAdvisory : SOGoFolderAdditionAdvisory
+@end
+
+@interface SOGoFolderBosnianAdditionAdvisory : SOGoFolderAdditionAdvisory
+@end
+
+@interface SOGoFolderArabicRemovalAdvisory : SOGoFolderRemovalAdvisory
+@end
+
+@interface SOGoFolderBosnianRemovalAdvisory : SOGoFolderRemovalAdvisory
+@end
+
 @interface SOGoFolderBrazilianPortugueseAdditionAdvisory : SOGoFolderAdditionAdvisory
 @end
 
 @interface SOGoFolderBrazilianPortugueseRemovalAdvisory : SOGoFolderRemovalAdvisory
 @end
 
+@interface SOGoFolderBulgarianAdditionAdvisory : SOGoFolderAdditionAdvisory
+@end
+
+@interface SOGoFolderBulgarianRemovalAdvisory : SOGoFolderRemovalAdvisory
+@end
+
 @interface SOGoFolderCzechAdditionAdvisory : SOGoFolderAdditionAdvisory
 @end
 
@@ -143,6 +161,18 @@
 @interface SOGoFolderLithuanianRemovalAdvisory : SOGoFolderRemovalAdvisory
 @end
 
+@interface SOGoFolderMacedonianAdditionAdvisory : SOGoFolderAdditionAdvisory
+@end
+
+@interface SOGoFolderMacedonianRemovalAdvisory : SOGoFolderRemovalAdvisory
+@end
+
+@interface SOGoFolderMontenegrinAdditionAdvisory : SOGoFolderAdditionAdvisory
+@end
+
+@interface SOGoFolderMontenegrinRemovalAdvisory : SOGoFolderRemovalAdvisory
+@end
+
 @interface SOGoFolderNorwegianBokmalAdditionAdvisory : SOGoFolderAdditionAdvisory
 @end
 
@@ -173,6 +203,18 @@
 @interface SOGoFolderRussianRemovalAdvisory : SOGoFolderRemovalAdvisory
 @end
 
+@interface SOGoFolderSerbianAdditionAdvisory : SOGoFolderAdditionAdvisory
+@end
+
+@interface SOGoFolderSerbianRemovalAdvisory : SOGoFolderRemovalAdvisory
+@end
+
+@interface SOGoFolderSerbianLatinAdditionAdvisory : SOGoFolderAdditionAdvisory
+@end
+
+@interface SOGoFolderSerbianLatinRemovalAdvisory : SOGoFolderRemovalAdvisory
+@end
+
 @interface SOGoFolderSpanishSpainAdditionAdvisory : SOGoFolderAdditionAdvisory
 @end
 
