@@ -225,12 +225,30 @@
 
 @end
 
+@implementation SOGoFolderArabicAdditionAdvisory
+@end
+
+@implementation SOGoFolderBosnianAdditionAdvisory
+@end
+
+@implementation SOGoFolderArabicRemovalAdvisory
+@end
+
+@implementation SOGoFolderBosnianRemovalAdvisory
+@end
+
 @implementation SOGoFolderBrazilianPortugueseAdditionAdvisory
 @end
 
 @implementation SOGoFolderBrazilianPortugueseRemovalAdvisory
 @end
 
+@implementation SOGoFolderBulgarianAdditionAdvisory
+@end
+
+@implementation SOGoFolderBulgarianRemovalAdvisory
+@end
+
 @implementation SOGoFolderCzechAdditionAdvisory
 @end
 
@@ -315,6 +333,18 @@
 @implementation SOGoFolderLithuanianRemovalAdvisory
 @end
 
+@implementation SOGoFolderMacedonianAdditionAdvisory
+@end
+
+@implementation SOGoFolderMacedonianRemovalAdvisory
+@end
+
+@implementation SOGoFolderMontenegrinAdditionAdvisory
+@end
+
+@implementation SOGoFolderMontenegrinRemovalAdvisory
+@end
+
 @implementation SOGoFolderNorwegianBokmalAdditionAdvisory
 @end
 
