@@ -44,7 +44,7 @@
 #import <SOGo/WOContext+SOGo.h>
 #import <SOGo/WOResourceManager+SOGo.h>
 
-#import "UIxJSClose.h"
+#import "UIxComponent.h"
 
 
 @interface UIxComponent (PrivateAPI)
@@ -448,17 +448,6 @@ static SoProduct      *commonProduct      = nil;
   return ([[self queryParameterForKey: @"noframe"] boolValue]);
 }
 
-- (UIxComponent *) jsCloseWithRefreshMethod: (NSString *) methodName
-{
-  UIxJSClose *jsClose;
-
-  jsClose = [UIxJSClose new];
-  [jsClose autorelease];
-  [jsClose setRefreshMethod: [methodName doubleQuotedString]];
-
-  return jsClose;
-}
-
 /* common conditions */
 - (BOOL) canCreateOrModify
 {
@@ -802,6 +791,7 @@ static SoProduct      *commonProduct      = nil;
   // If the action is 'connect' (or 'logoff'), we let it go as the token
   // needs to be created (or destroyed) during the session initialization
   if ([_actionName isEqualToString: @"connect"] ||
+      [_actionName isEqualToString: @"changePassword"] ||
       [_actionName isEqualToString: @"logoff"])
     {
       return [super performActionNamed: _actionName];
