@@ -319,8 +319,9 @@
     }
 
     this.$onDestroy = function () {
+      var noUpdate = true;
       editorElement.classList.add('ng-cloak');
-      editor.destroy();
+      editor.destroy(noUpdate);
     }
 
     function onInstanceReady (event) {
@@ -352,7 +353,7 @@
 
     function onEditorChange () {
       var html = editor.getData();
-      var body = editor.document.getBody();
+      var body = editor.document ? editor.document.getBody() : null;
       var text;
 
       if (_.isEmpty(body))
