@@ -98,6 +98,9 @@
         _.forEach(hotkeys, function(key) {
           sgHotkeys.deregisterHotkey(key);
         });
+        // Cancel automatic mark as read
+        if (vm.message.$markAsReadPromise)
+          vm.service.$timeout.cancel(vm.message.$markAsReadPromise);
       });
 
     }; // $onInit
@@ -148,7 +151,7 @@
         keys.push(sgHotkeys.createHotkey({
           key: hotkey,
           callback: _unlessInDialog(function($event) {
-            if (vm.mailbox.$selectedCount() === 0)
+            if (vm.mailbox.selectedCount() === 0)
               vm.deleteMessage();
             $event.preventDefault();
           }),
@@ -286,7 +289,7 @@
               $mdToast.show(
                 $mdToast.simple()
                   .textContent(l('Successfully created card'))
-                  .position('top right')
+                  .position(sgConstant.toastPosition)
                   .hideDelay(2000));
             });
           });
@@ -371,7 +374,7 @@
             else {
               state.go('mail.account.mailbox').then(function() {
                 message = null;
-                delete mailbox.selectedMessage;
+                delete mailbox.$selectedMessage;
               });
             }
           }
@@ -446,7 +449,7 @@
       var destination = Mailbox.$virtualMode ? 'mail.account.virtualMailbox' : 'mail.account.mailbox';
       $state.go(destination).then(function() {
         vm.message = null;
-        delete stateMailbox.selectedMessage;
+        delete stateMailbox.$selectedMessage;
       });
     };
 
@@ -485,7 +488,10 @@
                  this.message.uid]
           .join('/'),
           wId = this.message.$absolutePath();
-      if (action) url += '/' + action;
+      if (action) {
+        wId += '/' + action;
+        url += '/' + action;
+      }
       popupWindow = $window.open(url, wId,
                                  ["width=680",
                                   "height=520",
