@@ -9,7 +9,7 @@
    * @constructor
    */
   function Preferences() {
-    var _this = this, defaultsElement, settingsElement, data;
+    var _this = this, defaultsElement, settingsElement, data, time;
 
     this.nextAlarm = null;
     this.nextInboxPoll = null;
@@ -53,6 +53,13 @@
       if (data.SOGoRememberLastModule)
         data.SOGoLoginModule = "Last";
 
+      data.SOGoMailAutoMarkAsReadDelay = parseInt(data.SOGoMailAutoMarkAsReadDelay) || 0;
+      data.SOGoMailAutoMarkAsReadEnabled = (data.SOGoMailAutoMarkAsReadDelay >= 0);
+      if (data.SOGoMailAutoMarkAsReadDelay > 0)
+        data.SOGoMailAutoMarkAsReadMode = 'delay';
+      else
+        data.SOGoMailAutoMarkAsReadMode = 'immediate';
+
       // Mail editor autosave is a number of minutes or 0 if disabled
       data.SOGoMailAutoSave = parseInt(data.SOGoMailAutoSave) || 0;
 
@@ -77,18 +84,19 @@
       if (data.Vacation) {
         if (data.Vacation.startDate)
           data.Vacation.startDate = new Date(parseInt(data.Vacation.startDate) * 1000);
-        else {
-          data.Vacation.startDateEnabled = 0;
-          data.Vacation.startDate = new Date();
-          data.Vacation.startDate = data.Vacation.startDate.beginOfDay();
-          data.Vacation.startDate.addDays(1);
-        }
+
         if (data.Vacation.endDate)
           data.Vacation.endDate = new Date(parseInt(data.Vacation.endDate) * 1000);
-        else {
-          data.Vacation.endDateEnabled = 0;
-          data.Vacation.endDate = new Date(data.Vacation.startDate.getTime());
-          data.Vacation.endDate.addDays(1);
+
+        if (data.Vacation.startTime) {
+          time = data.Vacation.startTime.split(':');
+          data.Vacation.startTime = new Date();
+          data.Vacation.startTime.setHours(parseInt(time[0]), parseInt(time[1]));
+        }
+        if (data.Vacation.endTime) {
+          time = data.Vacation.endTime.split(':');
+          data.Vacation.endTime = new Date();
+          data.Vacation.endTime.setHours(parseInt(time[0]), parseInt(time[1]));
         }
         if (data.Vacation.autoReplyEmailAddresses &&
             angular.isString(data.Vacation.autoReplyEmailAddresses) &&
@@ -97,22 +105,42 @@
       } else
         data.Vacation = {};
 
+      if (angular.isUndefined(data.Vacation.days))
+        data.Vacation.days = [];
+
       if ((angular.isUndefined(data.Vacation.autoReplyEmailAddresses) ||
           data.Vacation.autoReplyEmailAddresses.length == 0) &&
           angular.isDefined(window.defaultEmailAddresses))
-        data.Vacation.autoReplyEmailAddresses = window.defaultEmailAddresses;
+        data.Vacation.autoReplyEmailAddresses = window.defaultEmailAddresses.slice();
 
       if (angular.isUndefined(data.Vacation.daysBetweenResponse))
         data.Vacation.daysBetweenResponse = 7;
 
-      if (angular.isUndefined(data.Vacation.startDate)) {
+      if (angular.isUndefined(data.Vacation.startDate) || !data.Vacation.startDate) {
         data.Vacation.startDateEnabled = 0;
         data.Vacation.startDate = new Date();
+        data.Vacation.startDate = data.Vacation.startDate.beginOfDay();
+        data.Vacation.startDate.addDays(1);
       }
 
-      if (angular.isUndefined(data.Vacation.endDate)) {
+      if (angular.isUndefined(data.Vacation.endDate) || !data.Vacation.endDate) {
         data.Vacation.endDateEnabled = 0;
-        data.Vacation.endDate = new Date();
+        data.Vacation.endDate = new Date(data.Vacation.startDate.getTime());
+        data.Vacation.endDate.addDays(1);
+      }
+
+      if (angular.isUndefined(data.Vacation.startTime) || !data.Vacation.startTime) {
+        data.Vacation.startTimeEnabled = 0;
+        data.Vacation.startTime = new Date();
+        data.Vacation.startTime.setHours(parseInt(data.SOGoDayEndTime));
+        data.Vacation.startTime.setMinutes(0);
+      }
+
+      if (angular.isUndefined(data.Vacation.endTime) || !data.Vacation.endTime) {
+        data.Vacation.endTimeEnabled = 0;
+        data.Vacation.endTime = new Date();
+        data.Vacation.endTime.setHours(parseInt(data.SOGoDayStartTime));
+        data.Vacation.endTime.setMinutes(0);
       }
 
       if (data.Forward) {
@@ -226,7 +254,7 @@
    * @desc The factory we'll use to register with Angular
    * @returns the Preferences constructor
    */
-  Preferences.$factory = ['$window', '$document', '$rootScope', '$q', '$timeout', '$log', '$state', '$mdDateLocale', '$mdToast', 'sgSettings', 'Gravatar', 'Resource', 'User', function($window, $document, $rootScope, $q, $timeout, $log, $state, $mdDateLocaleProvider, $mdToast, Settings, Gravatar, Resource, User) {
+  Preferences.$factory = ['$window', '$document', '$rootScope', '$q', '$timeout', '$log', '$state', '$mdDateLocale', '$mdToast', 'sgConstant', 'sgSettings', 'Gravatar', 'Resource', 'User', function($window, $document, $rootScope, $q, $timeout, $log, $state, $mdDateLocaleProvider, $mdToast, sgConstant, Settings, Gravatar, Resource, User) {
     angular.extend(Preferences, {
       $window: $window,
       $document: $document,
@@ -240,7 +268,8 @@
       $gravatar: Gravatar,
       $$resource: new Resource(Settings.activeUser('folderURL'), Settings.activeUser()),
       $resourcesURL: Settings.resourcesURL(),
-      $User: User
+      $User: User,
+      $sgConstant: sgConstant
     });
 
     return new Preferences(); // return unique instance
@@ -413,7 +442,19 @@
     if (this.inboxSyncToken)
       params.syncToken = this.inboxSyncToken;
 
-    Preferences.$$resource.post('Mail', '0/folderINBOX/changes', params).then(function(data) {
+    /**
+     * @ngInject
+     */
+    toastController.$inject = ['scope', '$mdToast', 'title', 'body'];
+    function toastController (scope, $mdToast, title, body) {
+      scope.title = title;
+      scope.body = body;
+      scope.close = function() {
+        $mdToast.hide('ok');
+      };
+    }
+
+    return Preferences.$$resource.post('Mail', '0/folderINBOX/changes', params).then(function(data) {
       if (data.syncToken) {
         _this.inboxSyncToken = data.syncToken;
         Preferences.$log.debug("New syncToken is " + _this.inboxSyncToken);
@@ -474,7 +515,7 @@
                   '  </div>',
                   '</md-toast>'
                 ].join(''),
-                position: 'top right',
+                position: Preferences.$sgConstant.toastPosition,
                 hideDelay: 5000,
                 controller: toastController,
                 viewInboxMessage: _this.viewInboxMessage
@@ -489,18 +530,6 @@
       if (refreshViewCheck && refreshViewCheck != 'manually')
         _this.nextInboxPoll = Preferences.$timeout(angular.bind(_this, _this.pollInbox), refreshViewCheck.timeInterval()*1000);
     });
-
-    /**
-     * @ngInject
-     */
-    toastController.$inject = ['scope', '$mdToast', 'title', 'body'];
-    function toastController (scope, $mdToast, title, body) {
-      scope.title = title;
-      scope.body = body;
-      scope.close = function() {
-        $mdToast.hide('ok');
-      };
-    }
   };
 
   /**
@@ -587,7 +616,7 @@
       }
       _this.currentToast = _this.currentToast.then(function () {
         return Preferences.$toast.show({
-          position: 'top right',
+          position: Preferences.$sgConstant.toastPosition,
           hideDelay: 0,
           template: [
             '<md-toast>',
@@ -698,6 +727,15 @@
     // Don't push locale definition
     delete preferences.defaults.locale;
 
+    if (preferences.defaults.SOGoMailAutoMarkAsReadEnabled) {
+      if (preferences.defaults.SOGoMailAutoMarkAsReadMode == 'immediate')
+        preferences.defaults.SOGoMailAutoMarkAsReadDelay = 0;
+    } else {
+      preferences.defaults.SOGoMailAutoMarkAsReadDelay = -1;
+    }
+    delete preferences.defaults.SOGoMailAutoMarkAsReadEnabled;
+    delete preferences.defaults.SOGoMailAutoMarkAsReadMode;
+
     // Merge back mail labels keys and values
     preferences.defaults.SOGoMailLabelsColors = {};
     _.forEach(preferences.defaults.SOGoMailLabelsColorsKeys, function(key, i) {
@@ -734,17 +772,35 @@
     delete preferences.defaults.SOGoMailComposeFontSizeEnabled;
 
     if (preferences.defaults.Vacation) {
-      if (preferences.defaults.Vacation.startDateEnabled)
+      if (preferences.defaults.Vacation.startDateEnabled) {
         preferences.defaults.Vacation.startDate = preferences.defaults.Vacation.startDate.getTime()/1000;
+      }
       else {
         delete preferences.defaults.Vacation.startDateEnabled;
-        preferences.defaults.Vacation.startDate = 0;
+        delete preferences.defaults.Vacation.startDate;
       }
       if (preferences.defaults.Vacation.endDateEnabled)
         preferences.defaults.Vacation.endDate = preferences.defaults.Vacation.endDate.getTime()/1000;
       else {
         delete preferences.defaults.Vacation.endDateEnabled;
-        preferences.defaults.Vacation.endDate = 0;
+        delete preferences.defaults.Vacation.endDate;
+      }
+
+      if (preferences.defaults.Vacation.startTimeEnabled) {
+        preferences.defaults.Vacation.startTime = preferences.defaults.Vacation.startTime.format(this.$mdDateLocaleProvider, '%H:%M');
+        // Set an end time only if a start time is defined
+        if (preferences.defaults.Vacation.endTimeEnabled)
+          preferences.defaults.Vacation.endTime = preferences.defaults.Vacation.endTime.format(this.$mdDateLocaleProvider, '%H:%M');
+        else {
+          delete preferences.defaults.Vacation.endTimeEnabled;
+          delete preferences.defaults.Vacation.endTime;
+        }
+      }
+      else {
+        delete preferences.defaults.Vacation.startTimeEnabled;
+        delete preferences.defaults.Vacation.startTime;
+        delete preferences.defaults.Vacation.endTimeEnabled;
+        delete preferences.defaults.Vacation.endTime;
       }
 
       if (preferences.defaults.Vacation.autoReplyEmailAddresses)
