@@ -25,6 +25,10 @@
         $mdConstant.KEY_CODE.COMMA,
         $mdConstant.KEY_CODE.SEMICOLON
       ];
+      if (Preferences.defaults.SOGoMailAutoMarkAsReadMode == 'delay')
+        this.mailAutoMarkAsReadDelay = Math.max(1, this.preferences.defaults.SOGoMailAutoMarkAsReadDelay);
+      else
+        this.mailAutoMarkAsReadDelay = 5;
 
       // Set alternate avatar in User service
       if (Preferences.defaults.SOGoAlternateAvatar)
@@ -107,6 +111,10 @@
       form.$setDirty();
     };
 
+    this.onMailAutoMarkAsReadDelay = function() {
+      this.preferences.defaults.SOGoMailAutoMarkAsReadDelay = this.mailAutoMarkAsReadDelay;
+    };
+
     this.addMailAccount = function(ev, form) {
       var account, index;
 
@@ -484,7 +492,7 @@
     };
 
     this.changePassword = function() {
-      Authentication.changePassword(this.passwords.newPassword, this.passwords.oldPassword).then(function() {
+      Authentication.changePassword(null, null, this.passwords.newPassword, this.passwords.oldPassword).then(function() {
         var alert = $mdDialog.alert({
           title: l('Password'),
           textContent: l('The password was changed successfully.'),
@@ -497,7 +505,7 @@
       }, function(msg) {
         var alert = $mdDialog.alert({
           title: l('Password'),
-          content: msg,
+          textContent: msg,
           ok: l('OK')
         });
         $mdDialog.show( alert )
@@ -587,6 +595,32 @@
 
       return r;
     };
+
+    this.toggleVacationStartTime = function() {
+      var v;
+
+      v = this.preferences.defaults.Vacation;
+
+      if (v.startTimeEnabled) {
+        // Enabling the start date
+        if (!v.startTime) {
+          v.startTime = new Date();
+        }
+      }
+    };
+
+    this.toggleVacationEndTime = function() {
+      var v;
+
+      v = this.preferences.defaults.Vacation;
+
+      if (v.endTimeEnabled) {
+        // Enabling the end date
+        if (!v.endTime) {
+          v.endTime = new Date();
+        }
+      }
+    };
   }
 
   angular
